@@ -6,5 +6,8 @@ logLik.varest <- function(object, ...){
   Sigma <- crossprod(resids) / obs
   r <- -( obs * K / 2 ) * log(2 * pi) - (obs / 2) * log(det(Sigma)) - (1 / 2) * sum(diag(resids %*% solve(Sigma) %*% t(resids)))
   class(r) <- "logLik"
+  params <- sum(unlist(lapply(object$varresult, function(x) length(coef(x)))))
+  attr(r, "df") <- params
+  attr(r, "nobs") <- object$obs
   return(r)
 }
